import { queryExtList } from '@/api/shopProduct'
const mallCategory = {
  template: `
      <a-cascader
        @change="handleChange"
        change-on-select 
        :changeOnSelect="true"
        :value="defaultVal"
        expand-trigger="hover"
        :options="categoryOptions"
        :fieldNames="{ label: 'categoryName', value: 'categorySn', children: 'shopCategoryList' }"
        :id="id"
        placeholder="请选择商城类目"
        allowClear />
    `,
  props: {
    value: {
      type: Array,
      default: function () {
        return []
      }
    },
    id: {
      type: String,
      default: ''
    },
    level: {
      type: Number,
      default: 3
    }
  },
  data () {
    return {
      defaultVal: this.value,
      categoryOptions: []
    }
  },
  watch: {
    value (newValue, oldValue) {
      this.defaultVal = newValue
    }
  },
  mounted () {
    this.getCategoryList()
  },
  methods: {
    // change时间
    handleChange (value) {
      this.defaultVal = value
      this.$emit('change', this.defaultVal)
    },
    // 格式化数据
    formatData (data) {
      if (this.level == 1) {
        data.forEach(item => {
          if (item.shopProductList) item.shopProductList = []
        })
      }
      if (this.level == 2) {
        data.forEach(item => {
          if (item.shopProductList) {
            item.shopProductList.forEach(child => {
              if (child.shopProductList) child.shopProductList = []
            })
          }
        })
      }
      return data
    },
    // 获取产品类目列表
    getCategoryList () {
      queryExtList({}).then(res => {
        if (res.status == 200) {
          this.categoryOptions = this.formatData(res.data)
        } else {
          this.categoryOptions = []
        }
      })
    }
  }
}

export default mallCategory
